@@ -978,12 +978,24 @@ class HeadingTestCase(_TranslationTestCase):
     '''
 
     styles_dict = {
-        'style0': 'heading 1',
-        'style1': 'heading 2',
-        'style2': 'heading 3',
-        'style3': 'heading 4',
-        'style4': 'heading 5',
-        'style5': 'heading 6',
+        'style0': {
+            'style_name': 'heading 1',
+        },
+        'style1': {
+            'style_name': 'heading 2',
+        },
+        'style2': {
+            'style_name': 'heading 3',
+        },
+        'style3': {
+            'style_name': 'heading 4',
+        },
+        'style4': {
+            'style_name': 'heading 5',
+        },
+        'style5': {
+            'style_name': 'heading 6',
+        },
     }
 
     def get_xml(self):
@@ -1004,6 +1016,54 @@ class HeadingTestCase(_TranslationTestCase):
         return xml
 
 
+class StyledBoldingTestCase(_TranslationTestCase):
+    expected_output = '''
+        <p><strong>AAA</strong></p>
+        <p><strong>BBB</strong></p>
+        <p>CCC</p>
+    '''
+
+    styles_dict = {
+        'style0': {
+            'style_name': 'p1',
+            'default_run_properties': {
+                'b': '',
+            }
+        },
+    }
+
+    def get_xml(self):
+        p_tags = [
+            DXB.p_tag(text='AAA', style='style0'),
+            DXB.p_tag(
+                [
+                    DXB.r_tag(
+                        [DXB.t_tag('BBB')],
+                        # Don't do duplicates
+                        rpr=DXB.rpr_tag({'b': None}),
+                    ),
+                ],
+                style='style0',
+            ),
+            DXB.p_tag(
+                [
+                    DXB.r_tag(
+                        [DXB.t_tag('CCC')],
+                        # Overwrite the current style
+                        rpr=DXB.rpr_tag({'b': 'false'}),
+                    ),
+                ],
+                style='style0',
+            ),
+        ]
+        body = ''
+        for tag in p_tags:
+            body += tag
+
+        xml = DXB.xml(body)
+        return xml
+
+
 class RomanNumeralToHeadingTestCase(_TranslationTestCase):
     convert_root_level_upper_roman = True
     numbering_dict = {
